/* Layout */
.container {
  max-width: 1120px;
  margin: 2rem auto;
  padding: 0 1rem;
}

.project-container {
  max-width: none;
  width: 80vw;
}

h1 {
  margin-bottom: 0.25rem;
  font-size: 1.75rem;
}

.page-header { margin: 0 0 0.75rem; }
.tab-nav {
  display: flex;
  gap: 1.5rem;
  align-items: baseline;
}
.tab-link {
  text-decoration: none;
  color: var(--muted);
  font-size: 1.05rem;
  font-weight: 600;
  padding-bottom: 0.2rem;
  border-bottom: 2px solid transparent;
  transition: color 0.15s ease, font-size 0.15s ease, border-color 0.15s ease;
}
.tab-link:hover { color: var(--text); }
.tab-link.active {
  color: var(--text);
  font-size: 1.75rem;
  font-weight: 700;
  border-color: var(--border-strong);
}
